@@ -44,28 +44,32 @@ def moveToNoRetest(rval, api):
             del rval["skipped"]["retest"][api]
     if "no-retest" in rval["skipped"]:
         if api in rval["skipped"]["no-retest"]:
-            for x in rval["skipped"]["no-retest"][api]:
-                if x["reason"].find("Also") < 0:
-                    x["reason"] += ". Also test calls with same attack type has generated passed/failed outcome."
+            if isinstance(rval["skipped"]["no-retest"][api], list):
+                for each_api in rval["skipped"]["no-retest"][api]:
+                    reason = each_api.get('reason')
+                if reason.find("Also") < 0 :
+                    rval["skipped"]["no-retest"][api][0]['reason'] += ". Also test calls with same attack type has generated passed/failed outcome."
+            else:
+                reason =rval["skipped"]["no-retest"][api].get('reason')
+                if reason.find("Also") < 0 :
+                    rval["skipped"]["no-retest"][api]['reason'] += ". Also test calls with same attack type has generated passed/failed outcome."
 # end moveToNoRetest
 
 
 def parseStdoutForInput(instdout):
-    debugstr = "for debugging:"
-    datastr = "\'data\':"
-    if instdout.find(debugstr) < 0:
-        return ""
-    sstr = instdout[instdout.find(debugstr)+len(debugstr):]
-    if sstr.find(datastr) < 0:
-        return ""
-    sstr = sstr[sstr.find(datastr) + len(datastr):]
-    headerstr = ", \'headers\':"
-    rvalsindx = sstr.find("{")
-    rvaleindx = sstr.find(headerstr)
-    if rvalsindx < 0 or rvaleindx < 0:
-        print("\n Debug == failed to extract inputstr from %s \n" % sstr)
-        return ""
-    return sstr[rvalsindx:rvaleindx]
+    request = ''
+    curl_str = 'CURL command to retry:'
+    delimiter_str = '\n\n---------------------------------\n\n'
+    curl_pos = instdout.find(curl_str)
+    if curl_pos < 0:
+        return request
+    curl_req_str = instdout[curl_pos + len(curl_str):]
+    del_pos = curl_req_str.find(delimiter_str)
+    if del_pos < 0:
+        request = curl_req_str
+    else:
+        request =  curl_req_str[:del_pos]
+    return request
 # end parseStdoutForInput
 
 #
@@ -323,7 +327,6 @@ def iterateallspecs(inspeclist=[], inattacklist=[]):
         }
         #print(theattacklist, "THEATTACXKLIST")
         for a in theattacklist:
-            #print(a, "Inattacklist")
             arname = a
             if arname.find("/"):
                 arname = arname.replace("/", "_")
@@ -392,16 +395,16 @@ def get_attack_catogery_count(report_json):
         res[key]['all_apis_count'] = len(value.get('all_apis', set()))
         if len(value.get('p1_apis', set())):
             res[key]['pri_count'] = len(value['p1_apis'])
-            res[key]['priority'] = 'P1'
+            res[key]['priority'] = 'Critical'
         elif len(value.get('p2_apis', set())):
             res[key]['pri_count'] = len(value['p2_apis'])
-            res[key]['priority'] = 'P2'
+            res[key]['priority'] = 'High'
         elif len(value.get('p3_apis', set())):
             res[key]['pri_count'] = len(value['p3_apis'])
-            res[key]['priority'] = 'P3'
+            res[key]['priority'] = 'Medium'
         else:
             res[key]['pri_count'] = len(value['p4_apis'])
-            res[key]['priority'] = 'P4'
+            res[key]['priority'] = 'Low'
     return res
 
 
@@ -430,6 +433,14 @@ def get_spec_details(report_json):
             if '/' in api_key:
                 values_list = []
                 for key, info in value.items():
+                    if info.get('pri', '') == 'p1':
+                        info['pri'] = 1
+                    elif info.get('pri', '') == 'p2':
+                        info['pri'] = 2
+                    elif info.get('pri', '') == 'p3':
+                        info['pri'] = 3
+                    else:
+                        info['pri'] = 4
                     values_list.append(info)
                 api_details[api_key] = values_list
         res[spec]['api_details'] = api_details
